
// TRD parameter file : full example with a description of the different
// instructions. Latest updates are marked with "*****"


// Any line starting by // is considered as a comment (any text)
// This can also be used to deactivate an instruction without erasing
// it, in this way giving a choice between several instructions.



// Short explanation of TexRD principle :
// Textures are made by simulating complex chemical reactions between
// various fluids (components), denoted A,B,C, etc... These reactions
// are causing spatial variations of the fluid concentrations. Such
// variations will in turn generate remarkable random patterns, which
// makes all the interest of TexRD.



// To run a texture computation, open the "Texture" menu and choose
// "Run". Results are saved on the hard disk as BMP images, in the
// same folder as the parameter file. This is a specific example, you
// will be prompted to save it under another name whether you want
// to run computation.



// Now, here are the successive steps when setting texture parameters.
// Steps 5 to 9 are easiest (like changing dimensions). Steps 2 to
// 4 are for advanced users. 


// STEP 1 : choose the reaction model.
// Each model has the capacity of producing one or several "classes of
// patterns", with a certain number of variations. The number of components
// also depends on the model.
// Syntax : "model <name of model>"
// Available models : GinzburgLandau, Maginu, Brusselator, GLD1, etc...
// Usually, one will start from the examples given for each model.

model GinzburgLandau




// STEP 2 : define the model parameters.
// Parameter names are different for each model. It is recommended to
// start with a working set of parameters and to make them change
// slightly if necessary. Load example files from "Parameters / Load..."
// menu, browse "Examples" folder.
// Syntax : "modpar <name of parameter> <value>"

modpar Alpha	1.0
modpar Gamma	1.0
modpar Delta	1.4

// ***** New in version 0.4b : it is now possible to make a model
// parameter vary during the computations.
// Syntax : "modpar <name of parameter> <value> [+/- optional increment]"
// Example : "modpar Delta 0.8 +0.001" means that Delta will start from 0.8
// and increase by 0.001 at each iteration




// STEP 3 : set the reaction and diffusion coefficients.
// By increasing the reaction rate, patterns are changing more rapidly, but
// their size decrease (scale change). It is advisable to let the diffusion
// coefficient at a value of 1.0, except for some specific cases, when very
// small patterns are needed. For certain models, one of the fluids must be
// more viscous, and this is another case when a lower diffusion coefficient
// has to be used. 
// Syntax : "reaction <component> <value>"
// and      "diffusion <component> <value> [+/- optional increment]"

// ***** New in version 0.3b : by option, it is possible to make the diffusion
// vary at each iteration. Example : "diffusion A 1.00 -0.001"  means that
// the diffusion starts at 1.00 (t=0), and then decreases by a value of 0.001
// at each iteration, until it levels off at the bottom value 0.0 (t=1000).
// Other example "diffusion B 0.50 +0.0002" (increases from 0.50 to 1.00)

reaction A	0.20
reaction B	0.20
diffusion A	1.00
diffusion B	1.00




// STEP 4 : Fix the initial state of every components.
// The random initial concentrations correspond to a "white noise".
// Pattern morphology can sometimes be changed by introducing an imbalance,
// with a different concentration for each component.
// Syntax: "init <component> <average value> <maximal range>"

init A		0.00 	0.50
init B		0.00	0.50
// means random concentrations between -0.50 and +0.50




// STEP 5 : simply change the size of the texture.
// Small dimensions give sometimes surprising results if one uses the
// texture for tiling. Try also very elongated formats (300 x 50 for
// instance). Computation times are proportional to the number of
// pixels, i.e. width x height
// Syntax : "size <width> <height>" (pixel values)

size		300 300




// STEP 6 : set the duration of computations.
// All models are taking place with time : chemical reactions are starting
// and then develop, which makes patterns to grow and change.
// Textures can be recorded at different steps of their transformations.
// One could even produce kind of a small movie (with a proper software
// that bases on a set of images). 
// Some models are chaotic (they change indefinitely), while others converge
// (but usually more an more slowly). Patterns are often becoming more regular
// with time.
// Syntax : "iterations <number of iterations>"

iterations	1000




// STEP 7 : eventually define the seed of the random number generator
// (when not set, the internal system clock is used to obtain a seed)
// To fix and preserve this seed allows exactly the same texture to be
// reproduced. Each seed gives a single result, but with the same kind
// of patterns since they are using the same model, with the same parameters.
// For instance, change only the seed if you want to get textures which
// have a similar look, but are all different. One can make a parallel
// with the fur of an animal (zebra, tiger,...) : each animal is unique
// but the patterns are identical for a given species.
// Syntax : "randseed <any integer number>"

// randseed 	440079




// STEP 8 : define how component concentrations are colorized : the color map.
// Advanced users can create their own color maps, or if not just copy the
// examples. Colors are set for the highest and lowest concentrations, and
// then the software calculates the color gradations for intermediate values. 
// Syntax : "colormap <type> <values....>", where "type" can be "gray" (gray
// levels), "rgb" (red-green-blue), "hsl" (hue-saturation-luminance), "xyz"
// (another red-green-blue model) or "cmyk" (cyan-magenta-yellow-black)
// Except for "gray", one should give color values that correspond to the
// minimum and maximum values of each color channel (e.g. 6 values for "rgb" :
// mini.red, maxi.red, mini.green, maxi.green, mini.blue, maxi.blue)
// One can introduce some color frequencies by going several times over the
// maximum. Example : "rgb O 512....." means for red channel : 0 -> 255 -> 0

// A few samples. Activate one of the color maps by withdrawing "//" at the
// beginning of a line. Only one color map must be active, add "//" to the
// previous active one.

// Black and white color map
// colormap gray

// Rainbow colormap (blue -> red = low -> high concentrations)
colormap hsl  250 0    0.9 0.9    255 255
// 250 corresponds to the blue color and 0 to the red (decreasing gradation)
// 0.9 0.9 : saturation remains constant (values between 0 and 1)
// 255 255 : same for luminance (values between 0 and 255)

// Here are a few color maps which give more artistic effects :
// colormap hsl  50 200   0.3 0.5   50 768
// colormap rgb  0 768    50 50     255 255

// ***** Version 0.4b : two new types of color maps (new color spaces)
// (1) XYZ mini/maxi red, mini/maxi green, mini/maxi blue
//     with all values between 0 and 1
//     Example : colormap xyz  0.2 0.3    0.1 0.4    0.4 0.8
// (2) CMYK mini/maxi cyan, mini/maxi magenta, mini/maxi yellow, mini/maxi black 
//     with all values between 0 and 255
//     Example : colormap cmyk  1600 50   20 200   0 100   100 4000




// STEP 9  : select which images are to be saved : which component, at which
// frequency, and the scaling transformation to pass from concentrations
// (floating point numbers) to integer values ranging from 1 to 254 - the
// values used in a standard 256 color BMP image.
// Black zones will appear if one overflows the [1:254] interval by the bottom,
// and white zones by the top. Using the "autoscale" mode, minimal and maximal
// concentrations will be detected at each iteration and fit to the values 1
// and 254 respectively. In this case, no overflow can occur but the scaling
// transformation will be different at each iteration.
// Syntax 1 : "image256 <component> t+<interval> *<normalize> +<shift>"
// Syntax 2 (automatic scaling) : "image256 <component> t+<interval> autoscale"

// Save the system state every 200 iterations :
image256 A t+200 *122.0 +128.0

// ***** New features of version 0.3b about image saving :

// (1) 16 millions of colors format (24 bits).
// Recommended if the color map contains numerous variations (color
// frequencies), useless otherwise
// Syntax : "image16M <component> t+<interval> *<normalize> +<shift>"
// To make it simpler, normalization and shift are identical for both "image256"
// and "image16M" instructions (use same values)
// Examples : "image16M A t+200 *122.0 +128.0", "image16M C t+3000 autoscale"

// (2) Delayed saving start
// Example "image256 A 1500<t+200 autoscale" : in this case, images start to be
// recorded only from t=1500 and then at t=1700, 1900, 2100...


// **** New features of version 0.4b about image saving :

// (1) Direct generation of mosaics (avoid using external software)
// Syntax : add "mosaic <width> <height>" at the end of parameters
// for the instructions "image256" or "image16M"
// Example : "image16M A t+500 autoscale mosaic 600 500" means that an image
// with the size 600 x 500 will be produced by tiling the texture.

// (2) TGA format saving (by default, BMP format is used)
// Syntax : add "TGA" at the end of parameters for "image256" or "image16M"
// Examples : "image16M B t+200 *90.0 +128.0 TGA"
//            "image256 A t+90 autoscale mosaic 400 100 TGA"



